==> muslimdata-1.2.0-sources.jar: dev/kosrat/muslimdata/extensions/DateUtil.kt <==
package dev.kosrat.muslimdata.extensions

import dev.kosrat.muslimdata.models.TimeFormat
import java.text.SimpleDateFormat
import java.util.*

/**
 * Format date to match the database date style.
 * Pattern: MM-dd
 */
internal fun Date.formatToDBDate(): String {
    val sdf = SimpleDateFormat("MM-dd", Locale.ENGLISH)
    return sdf.format(this)
}

/**
 * Format time to be 12 or 24 time format.
 */
internal fun Date.format(format: TimeFormat, locale: Locale): String {
    return when (format) {
        TimeFormat.TIME_24 -> {
            val sdf = SimpleDateFormat("HH:mm", locale)
            sdf.format(this)
        }
        TimeFormat.TIME_12 -> {
            val sdf = SimpleDateFormat("hh:mm a", locale)
            sdf.format(this)
        }
    }
}

/**
 * Convert database string date to date.
 */
internal fun String.toDate(date: Date): Date {
    val calendar = Calendar.getInstance()
    calendar.time = date
    val hourMinute = this.split(":")
    val hour = hourMinute[0].toInt()
    val minute = hourMinute[1].toInt()
    calendar.set(Calendar.HOUR_OF_DAY, hour)
    calendar.set(Calendar.MINUTE, minute)
    calendar.set(Calendar.SECOND, 0)
    calendar.set(Calendar.MILLISECOND, 0)

    return calendar.time
}

/**
 * Add field date to the current date.
 */
internal fun Date.add(field: Int, amount: Int): Date {
    Calendar.getInstance().apply {
        time = this@add
        add(field, amount)
        return time
    }
}

/**
 * Add years to the current date.
 */
internal fun Date.addYears(years: Int): Date {
    return add(Calendar.YEAR, years)
}

/**
 * Add months to the current date.
 */
internal fun Date.addMonths(months: Int): Date {
    return add(Calendar.MONTH, months)
}

/**
 * Add days to the current date.
 */
internal fun Date.addDays(days: Int): Date {
    return add(Calendar.DAY_OF_MONTH, days)
}

/**
 * Add hours to the current date.
 */
internal fun Date.addHours(hours: Int): Date {
    return add(Calendar.HOUR_OF_DAY, hours)
}

/**
 * Add minutes to the current date.
 */
internal fun Date.addMinutes(minutes: Int): Date {
    return add(Calendar.MINUTE, minutes)
}

/**
 * Add seconds to the current date.
 */
internal fun Date.addSeconds(seconds: Int): Date {
    return add(Calendar.SECOND, seconds)
}

==> muslimdata-1.3.4-sources.jar: dev/kosrat/muslimdata/extensions/DateUtil.kt <==
package dev.kosrat.muslimdata.extensions

import android.os.Build
import dev.kosrat.muslimdata.models.TimeFormat
import java.text.SimpleDateFormat
import java.util.*

/**
 * Format date to match the database date style.
 * Pattern: MM-dd
 */
internal fun Date.formatToDBDate(): String {
    val sdf = SimpleDateFormat("MM-dd", Locale.ENGLISH)
    return sdf.format(this)
}

/**
 * Format time to be 12 or 24 time format.
 */
internal fun Date.format(format: TimeFormat, locale: Locale): String {
    return when (format) {
        TimeFormat.TIME_24 -> {
            formatTime24(locale)
        }
        TimeFormat.TIME_12 -> {
            formatTime12(locale)
        }
    }
}

private fun Date.formatTime24(locale: Locale): String {
    val sdf = SimpleDateFormat("HH:mm", locale)
    return sdf.format(this)
}

private fun Date.formatTime12(locale: Locale): String {
    return if (Build.VERSION.SDK_INT < 26 && locale.language == "ckb") {
        val sdf = SimpleDateFormat("hh:mm a", Locale("ar"))
        sdf.format(this).replace("م", "د.ن").replace("ص", "ب.ن")
    } else {
        val sdf = SimpleDateFormat("hh:mm a", locale)
        sdf.format(this)
    }
}

/**
 * Convert database string date to date.
 */
internal fun String.toDate(date: Date): Date {
    val calendar = Calendar.getInstance()
    calendar.time = date
    val hourMinute = this.split(":")
    val hour = hourMinute[0].toInt()
    val minute = hourMinute[1].toInt()
    calendar.set(Calendar.HOUR_OF_DAY, hour)
    calendar.set(Calendar.MINUTE, minute)
    calendar.set(Calendar.SECOND, 0)
    calendar.set(Calendar.MILLISECOND, 0)

    return calendar.time
}

/**
 * Add field date to the current date.
 */
internal fun Date.add(field: Int, amount: Int): Date {
    Calendar.getInstance().apply {
        time = this@add
        add(field, amount)
        return time
    }
}

/**
 * Add years to the current date.
 */
internal fun Date.addYears(years: Int): Date {
    return add(Calendar.YEAR, years)
}

/**
 * Add months to the current date.
 */
internal fun Date.addMonths(months: Int): Date {
    return add(Calendar.MONTH, months)
}

/**
 * Add days to the current date.
 */
internal fun Date.addDays(days: Int): Date {
    return add(Calendar.DAY_OF_MONTH, days)
}

/**
 * Add hours to the current date.
 */
internal fun Date.addHours(hours: Int): Date {
    return add(Calendar.HOUR_OF_DAY, hours)
}

/**
 * Add minutes to the current date.
 */
internal fun Date.addMinutes(minutes: Int): Date {
    return add(Calendar.MINUTE, minutes)
}

/**
 * Add seconds to the current date.
 */
internal fun Date.addSeconds(seconds: Int): Date {
    return add(Calendar.SECOND, seconds)
}
